# LaTeX2HTML 2008 (1.71)
# Associate labels original text with physical files.


$key = q/SubSec:CPP/;
$external_labels{$key} = "$URL/" . q|developer_man.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Inst/;
$external_labels{$key} = "$URL/" . q|developer_man.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Conflicts/;
$external_labels{$key} = "$URL/" . q|developer_man.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Bugs/;
$external_labels{$key} = "$URL/" . q|developer_man.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:conf/;
$external_labels{$key} = "$URL/" . q|developer_man.html|; 
$noresave{$key} = "$nosave";

$key = q/Sec:SVN/;
$external_labels{$key} = "$URL/" . q|developer_man.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Merge/;
$external_labels{$key} = "$URL/" . q|developer_man.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:propedit/;
$external_labels{$key} = "$URL/" . q|developer_man.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2008 (1.71)
# labels from external_latex_labels array.


$key = q/SubSec:propedit/;
$external_latex_labels{$key} = q|11.4|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Merge/;
$external_latex_labels{$key} = q|11.3|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:conf/;
$external_latex_labels{$key} = q|5.1.2|; 
$noresave{$key} = "$nosave";

$key = q/Sec:SVN/;
$external_latex_labels{$key} = q|11|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Bugs/;
$external_latex_labels{$key} = q|3.5|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Inst/;
$external_latex_labels{$key} = q|5.1|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:CPP/;
$external_latex_labels{$key} = q|5.1.1|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Conflicts/;
$external_latex_labels{$key} = q|11.2|; 
$noresave{$key} = "$nosave";

$key = q/_oldnewlabel/;
$external_latex_labels{$key} = q|<|; 
$noresave{$key} = "$nosave";

1;

